/*
 * Copyright (c) 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */

// Names, usernames, and organization names come from generated mock data.

// Mocks the response of `getInterestGroupParticipatingOrganizations()`
export const mockParticipatingOrganizationsCategorizedByInterestGroup = {
  'models-for-privacy-engineering': [
    {
      organizationId: '111',
      name: 'Schmidt Group',
      logos: {
        print: null,
        web: 'https://membership.eclipse.org/organization/images/111-web.png',
      },
      levels: [
        {
          level: 'SD',
          description: 'Strategic Member',
          sort_order: '500',
        },
      ],
    },
    {
      organizationId: '112',
      name: 'Williamson-Abernathy',
      logos: {
        print: null,
        web: 'https://membership.eclipse.org/organization/images/112-web.png',
      },
      levels: [
        {
          level: 'AP',
          description: 'Contributing Member',
          sort_order: '200',
        },
      ],
    },
    {
      organizationId: '112',
      name: 'Williamson-Abernathy',
      logos: {
        print: null,
        web: 'https://membership.eclipse.org/organization/images/112-web.png',
      },
      levels: [
        {
          level: 'AP',
          description: 'Contributing Member',
          sort_order: '200',
        },
      ],
    },
  ],
  'openmobility': [
    { 
      organizationId: '105',
      name: 'Beahan LLC',
      logos: {
        print: null,
        web: 'https://membership.eclipse.org/organization/images/105-web.png',
      },
      levels: [
        {
          level: 'SD',
          name: 'Strategic Member',
          sort_order: '500'
        }
      ]
    },
    { 
      organizationId: '106',
      name: 'Lebsack Inc',
      logos: {
        print: null,
        web: 'https://membership.eclipse.org/organization/images/106-web.png',
      },
      levels: [
        {
          level: 'AP',
          name: 'Contributing Member',
          sort_order: '200'
        }
      ]
    },
    { 
      organizationId: '107',
      name: 'Koepp Inc',
      logos: {
        print: null,
        web: 'https://membership.eclipse.org/organization/images/107-web.png',
      },
      levels: [
        {
          level: 'AP',
          name: 'Contributing Member',
          sort_order: '200'
        }
      ]
    },
  ]
};

export const mockInterestGroups = [
  {
    id: '25810',
    title: 'openMobility',
    description: {
      summary: '',
      full: '<p>The openMobility interest group will drive the evolution and broad adoption of mobility modelling and simulation technologies. It accomplishes its goal by fostering and leveraging collaborations among members. It is the goal of this interest group to deliver a methodology and a framework of tools based on validated models, which are accepted as \u201cstandard tools\u201d in industry applications and academia for mobility modelling and simulation. Eclipse Foundation projects related to the openMobility interest group will provide technical implementations.</p>\n<p>Public mailing list:\u00a0<a href="https://www.eclipse.org/lists/openmobility" rel="nofollow">https://www.eclipse.org/lists/openmobility</a></p>',
    },
    logo: '',
    scope: {
      summary: '',
      full: '<p>The openMobility interest group will provide a place for collaboration and strategic coordination for Eclipse Foundation projects on the following topics:</p>\n<ul><li>Microscopic and Mesoscopic Traffic Simulation</li>\n<li>Mobility demand generation</li>\n<li>Vehicle-to-Vehicle and Vehicle-to-Infrastructure Communication Simulation</li>\n<li>Pedestrian Dynamics Simulation</li>\n<li>Simulator Coupling infrastructure</li>\n<li>Interfaces to Advanced Driver Assistance Systems and Intelligent Transportation Systems solutions</li>\n</ul><p>\u00a0</p>',
    },
    leads: [
      {
        username: 'tcrimes3',
        full_name: 'Tam Crimes',
        url: 'https://api.eclipse.org/account/profile/tcrimes3',
        organization: {
          id: '105',
          name: 'Beahan LLC',
          documents: { mcca: true },
        },
      },
      {
        username: 'tslateford8',
        full_name: 'Toddy Slateford',
        url: 'https://api.eclipse.org/account/profile/tslateford8',
        organization: {
          id: '105',
          name: 'Beahan LLC',
          documents: { mcca: true },
        },
      },
    ],
    participants: [
      {
        username: 'dslotp',
        full_name: 'Dodie Slot',
        url: 'https://api.eclipse.org/account/profile/dslotp',
        organization: { id: '106', name: 'Lebsack Inc', documents: { mcca: true } },
      },
      {
        username: 'tould10',
        full_name: 'Thelma Ould',
        url: 'https://api.eclipse.org/account/profile/tould10',
        organization: { id: '107', name: 'Koepp Inc', documents: { mcca: true } },
      },
    ],
    project_id: 'foundation-internal.ig.openmobility',
    short_project_id: 'openmobility',
    state: 'active',
    gitlab: { project_group: 'eclipse-ig/openmobility', ignored_sub_groups: [] },
    resources: { website: '', members: '' },
    mailing_list: '',
  },
  {
    id: '26148',
    title: 'Models for privacy engineering',
    description: {
      summary: '',
      full: '<h4><strong>Sharing practices for privacy engineering based on models</strong></h4>\n<p>This interest group focuses on the sharing of practices for privacy engineering based on the use of\u00a0 models:</p>\n<ul><li>To foster exchange of ideas and explanation. This is a universal practice, as pointed out by the national science teaching association, which has developed a practice program which leverages models as helpful tools for representing ideas and explanations. These tools include diagrams, drawings, physical replicas, mathematical representations, analogies, and computer simulations (https://ngss.nsta.org/Practices.aspx?id=2).</li>\n<li>To support engineering. INCOSE defines model-based systems engineering (MBSE) as the formalized application of modeling to support system requirements, design, analysis, verification and validation activities beginning in the conceptual design phase and continuing throughout development and later life cycle phases (https://www.omgwiki.org/MBSE/doku.php).</li>\n</ul><p>Models can be used</p>\n<ul><li>as a common language for descriptive capabilities, so that system models include any information about the system and its context that may be necessary to address privacy concerns from different viewpoints (e.g. requirements specification, logical data structure, processing functions, architectural deployment, development process, assurance evidence, external threats, etc.).</li>\n<li>as an information sharing tool for prescriptive capabilities, so that the capabilities of available leading solutions are described in shared terms that allow documenting them, comparing them, choosing those most appropriate for a given situation.</li>\n</ul><h4><strong>Creating synergies to foster the development of an ecosystem of privacy models</strong></h4>\n<p>While a lot of work is underway by different groups (e.g., privacy threat modelling, privacy patterns, privacy enhancing technologies), this interest group will serve to create synergies and collaboration, addressing the following needs:</p>\n<p>(1) Enabling the combination of multiple viewpoints on privacy, integrating</p>\n<ul><li>the consumer\u2019s viewpoint (e.g. see ISO 31700-1 - https://www.iso.org/standard/84977.html),</li>\n<li>the technology realm (e.g., IoT, Artificial intelligence, digital twin),</li>\n<li>the application domains (e.g., health, energy, transport),</li>\n<li>solutions (e.g., privacy controls, privacy enhancing technologies), and</li>\n<li>the product lifecycle (e.g., from inception to end of use/end of support) and data lifecycle (e.g., from collection to deletion of data).</li>\n</ul><p>(2) Guidance on privacy practices,</p>\n<ul><li>at the level of training and awareness creation (e.g., NIST privacy workforce program - https://www.nist.gov/privacy-framework/workforce-advancement/privacy-workforce-public-working-group, IAPP Privacy Engineering),</li>\n<li>at the level of privacy threat assessment (e.g., LINDDUN - https://www.linddun.org/), or</li>\n<li>at the level of trustworthiness and compliance (e.g. standards - https://ipen.trialog.com/wiki/ISO)</li>\n</ul><p>(3) Sharing information on available leading solutions for privacy engineering based on the use of models, i.e., solutions for privacy that correspond to the state of the art (leading) and that have sufficient maturity (available). This can leverage the use of catalogues of patterns for privacy engineering (patterns are abstractions of effectively proven solutions that can be systematically applied to address typical problems under commonly occurring contexts, see https://hillside.net/patterns/about-patterns)</p>',
    },
    logo: '',
    scope: {
      summary: '',
      full: '<p>The<strong> models for privacy engineering </strong>interest group promotes the use, creation and sharing of privacy models (1) as a common language for descriptive capabilities, (2) as an information sharing tool for prescriptive capabilities. Activities will include</p>\n<ul><li>Creating of awareness on privacy models, through collaborations with other communities (e.g., IAPP, ISACA, CPDP, EclipseCon, privacy-patterns.org) and initiatives (e.g., LINDDUN, NIST privacy framework)</li>\n<li>Contributing to privacy engineering roadmaps on the integration of practices based on privacy models. In can include topics such as governance and policies, privacy capabilities, privacy compliance.</li>\n<li>Contributing to privacy engineering standards on the integration of practices based on privacy models.</li>\n<li>Issuing recommendations for information sharing of privacy models and solutions while taking into account IPR restrictions\u00a0</li>\n</ul><p>The <strong>models for privacy engineering </strong> interest group will provide an annual report.</p>\n<p>It is not in the scope of the interest group to develop specific models, nor to operate a privacy model repository.</p>\n<p>\u00a0</p>',
    },
    leads: [
      {
        username: 'nivakhno1t',
        full_name: 'Nicoli Ivakhno',
        url: 'https://api.eclipse.org/account/profile/akung',
        organization: { id: '', name: '', documents: { mcca: false } },
      },
    ],
    participants: [
      {
        username: 'kelassal2c3',
        full_name: 'Karim El Assal',
        url: 'https://api.eclipse.org/account/profile/kelassal2c3',
        organization: {
          id: '1489',
          name: 'Netherlands Organisation for applied scientific research TNO',
          documents: { mcca: true },
        },
      },
      {
        username: 'eriosw04',
        full_name: 'Erkuden Rios',
        url: 'https://api.eclipse.org/account/profile/eriosw04',
        organization: {
          id: '998',
          name: 'FUNDACI\u00d3N TECNALIA RESEARCH & INNOVATION',
          documents: { mcca: false },
        },
      },
      {
        username: 'albertoberreteaga',
        full_name: 'Alberto Berreteaga',
        url: 'https://api.eclipse.org/account/profile/albertoberreteaga',
        organization: {
          id: '998',
          name: 'FUNDACI\u00d3N TECNALIA RESEARCH & INNOVATION',
          documents: { mcca: false },
        },
      },
      {
        username: 'tritter',
        full_name: 'Tom Ritter',
        url: 'https://api.eclipse.org/account/profile/tritter',
        organization: { id: '758', name: 'Fraunhofer-Gesellschaft', documents: { mcca: true } },
      },
    ],
    project_id: '',
    short_project_id: '',
    state: 'pre_proposal',
    gitlab: { project_group: '', ignored_sub_groups: [] },
    resources: { website: '', members: '' },
    mailing_list: '',
  },
];
